import React, { useCallback, useContext, useMemo, useRef } from 'react';
import { observer } from 'mobx-react-lite';
import Alert from '../../../es/alert';
import { getConfig } from '../../../es/configure';
import Popover from '../../../es/popover';
import { action } from 'mobx';
import Radio from '../radio';
import Typography from '../typography';
import isOverflow from '../overflow-tip/util';
import { hide, show } from '../tooltip/singleton';
import { exportExcel } from '../data-set/utils';
import TableContext from './TableContext';
import { $l } from '../locale-context';
import Tooltip from '../tooltip';
import Button from '../button';
import { ButtonColor, FuncType } from '../button/enum';
import { Size } from '../core/enum';
import message from '../message';
var Text = Typography.Text;

var ClipboardBar = function ClipboardBar(props) {
  var clipboard = props.clipboard;

  var _useContext = useContext(TableContext),
      tableStore = _useContext.tableStore,
      prefixCls = _useContext.prefixCls,
      dataSet = _useContext.dataSet;

  var refText = useRef(null);
  var handleDownloadtemplate = useCallback(function () {
    var getXlsxConfig = getConfig('xlsx');

    if (getXlsxConfig.name !== 'xlsx') {
      message.warning($l('Table', 'no_xlsx'));
      return;
    }

    var leafs = tableStore.columnGroups.leafs;
    var templateHeader = {}; // 表头

    var templateType = {}; // 字段类型

    var templateIsMutiple = {}; // 是否多值

    for (var i = 0; i < leafs.length; i++) {
      var item = leafs[i];
      var columnName = item && item.column.name;

      if (columnName) {
        var field = dataSet.fields.get(columnName);

        if (field) {
          var label = field.get('label');
          var type = field.get('type');
          var isMutiple = field.get('multiple');
          templateHeader[columnName] = label;
          templateType[columnName] = type;
          templateIsMutiple[columnName] = isMutiple;
        }
      }
    }

    var data = []; // 模拟 5 条数据

    var _loop = function _loop(_i) {
      var row = {};
      Object.keys(templateHeader).forEach(function (key) {
        switch (templateType[key]) {
          case "string":
          case "intl":
            row[key] = templateIsMutiple[key] ? '文字1,文字2' : '文字';
            break;

          case "number":
            row[key] = templateIsMutiple[key] ? "10, 20" : Math.floor(Math.random() * 100 + 1);
            break;

          case "boolean":
            row[key] = Math.random() > 0.5 ? "是" : "否";
            break;

          case "object":
            row[key] = templateIsMutiple[key] ? "LOV相关文字1,LOV相关文字2" : "LOV相关文字";
            break;

          case "date":
            row[key] = templateIsMutiple[key] ? "2023-07-01,2023-07-02" : "2023-07-01";
            break;

          case "dateTime":
            row[key] = templateIsMutiple[key] ? "2023-07-01 12:12:12,2023-07-02 13:13:13" : "2023-07-01 12:12:12";
            break;

          case "year":
            row[key] = templateIsMutiple[key] ? '2023,2024' : '2023';
            break;

          case "week":
            row[key] = templateIsMutiple[key] ? '2023-20周,2023-21周' : '2023-20周';
            break;

          case "month":
            row[key] = templateIsMutiple[key] ? '2023-01,2024-01' : '2023-01';
            break;

          case "time":
            row[key] = templateIsMutiple[key] ? '05:05:00,16:14:15' : '16:14:15';
            break;

          case "email":
            row[key] = templateIsMutiple[key] ? 'xxxxxx@xxx.com,zzzzz@zzz.com' : 'xxxxxx@xxx.com';
            break;

          case "url":
            row[key] = templateIsMutiple[key] ? 'https:www.xxxxxx.com/,https:www.zzzzzz.com/' : 'https:www.xxxxxx.com/';
            break;

          case "bigNumber":
            row[key] = templateIsMutiple[key] ? '123456789.123456789,1000000.000000001' : '123456789.123456789';
            break;

          default:
            break;
        }
      });
      data.push(row);
    };

    for (var _i = 0; _i < 5; _i++) {
      _loop(_i);
    }

    data.unshift(templateHeader);
    exportExcel(data, $l('Table', 'paste_template'), getXlsxConfig);
  }, [dataSet]);
  var clipboardDescription = useMemo(function () {
    if (clipboard.description) {
      return clipboard.description;
    }

    var isMac = navigator.platform.toLowerCase().includes('mac');
    var info = [/*#__PURE__*/React.createElement("span", {
      key: "info-header"
    }, $l('Table', 'table_support'))];

    if (clipboard.copy) {
      info.push( /*#__PURE__*/React.createElement("span", {
        key: "info-copy"
      }, " ", /*#__PURE__*/React.createElement(Text, {
        keyboard: true
      }, isMac ? 'command' : 'CTRL', "+C"), " ", $l('Table', 'ctrl_c_info')));
    }

    if (clipboard.paste) {
      info.push( /*#__PURE__*/React.createElement("span", {
        key: "info-paste"
      }, " ", /*#__PURE__*/React.createElement(Text, {
        keyboard: true
      }, isMac ? 'command' : 'CTRL', "+V"), " ", $l('Table', 'ctrl_v_info')));
    }

    return info;
  }, [clipboard]);
  var handleChange = useCallback(action(function (value) {
    tableStore.isCopyPristine = value === 'pristine'; // 切换之后，Table 聚焦

    tableStore.node.focus();
  }), []);
  var suffixInfo = useMemo(function () {
    var btn = [];

    if (clipboard.copy) {
      btn.push( /*#__PURE__*/React.createElement(Popover, {
        key: "clipboard-copy",
        trigger: "hover",
        content: /*#__PURE__*/React.createElement("form", null, /*#__PURE__*/React.createElement(Radio, {
          name: "base",
          value: "display",
          defaultChecked: true,
          onChange: handleChange
        }, $l('Table', 'copy_display')), /*#__PURE__*/React.createElement(Radio, {
          name: "base",
          value: "pristine",
          onChange: handleChange
        }, $l('Table', 'copy_pristine')))
      }, /*#__PURE__*/React.createElement("a", null, $l('Table', 'copy_config'))));
    }

    if (clipboard.paste) {
      btn.push([/*#__PURE__*/React.createElement("a", {
        key: "clipboard-paste",
        onClick: handleDownloadtemplate,
        style: {
          marginLeft: clipboard.copy ? '0.16rem' : 0
        }
      }, $l('Table', 'download_table_template')), /*#__PURE__*/React.createElement(Tooltip, {
        title: $l('Table', 'download_table_template_tooltip'),
        theme: "light",
        key: "download_table_template"
      }, /*#__PURE__*/React.createElement(Button, {
        funcType: FuncType.flat,
        color: ButtonColor.primary,
        size: Size.small,
        icon: 'help_outline'
      }))]);
    }

    return btn;
  }, [clipboard]);
  var handleMouseEnter = useCallback(function () {
    if (refText.current && isOverflow(refText.current)) {
      show(refText.current, {
        title: clipboardDescription,
        theme: 'dark'
      });
    }
  }, [clipboard, refText]);
  var handleMouseLeave = useCallback(function () {
    if (refText.current) {
      hide();
    }
  }, [refText]);
  return /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-clipboard")
  }, /*#__PURE__*/React.createElement(Alert, {
    message: /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-clipboard-content")
    }, /*#__PURE__*/React.createElement("div", {
      ref: refText,
      className: "".concat(prefixCls, "-clipboard-content-text"),
      onMouseEnter: handleMouseEnter,
      onMouseLeave: handleMouseLeave
    }, clipboardDescription), /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-clipboard-content-suffix")
    }, suffixInfo)),
    type: "info",
    showIcon: true
  }));
};

ClipboardBar.displayName = 'ClipboardBar';
export default observer(ClipboardBar);
//# sourceMappingURL=ClipboardBar.js.map
